argumentsOfInterestFor method
Return the arguments that we care about for the select. In this case they will all be passed in as a Map rather than as the named arguments used in Plural/Gender.
Implementation
@override
Map argumentsOfInterestFor(MethodInvocation node) {
SetOrMapLiteral casesArgument =
node.argumentList.arguments[1] as SetOrMapLiteral;
return {
for (final MapLiteralEntry node
in casesArgument.elements.whereType<MapLiteralEntry>())
_keyForm(node.key): node.value,
};
}